<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR" sourcelanguage="fr">
<context>
    <name>StartQT4</name>
    <message>
        <location filename="pymecavideo.py" line="308"/>
        <source>indéf</source>
        <translation type="obsolete">indéf</translation>
    </message>
    <message>
        <location filename="." line="115414494"/>
        <source>indéf.</source>
        <comment>utf8</comment>
        <translation type="obsolete">indéf.</translation>
    </message>
    <message>
        <location filename="." line="0"/>
        <source>temps en seconde, positions en mètre</source>
        <translation type="obsolete">temps en seconde, positions en mètre</translation>
    </message>
    <message>
        <location filename="." line="0"/>
        <source>point N°</source>
        <translation type="obsolete">point N°</translation>
    </message>
    <message>
        <location filename="." line="0"/>
        <source>Evolution de l&apos;ordonnée du point %1</source>
        <translation type="obsolete">Evolution de l&apos;ordonnée du point %1</translation>
    </message>
    <message>
        <location filename="." line="0"/>
        <source>Vous avez atteint la fin de la vidéo</source>
        <translation type="obsolete">Vous avez atteint la fin de la vidéo</translation>
    </message>
    <message>
        <location filename="." line="49"/>
        <source>Quelle est la longueur en mètre de votre étalon sur l&apos;image ?</source>
        <translation type="obsolete">Quelle est la longueur en mètre de votre étalon sur l&apos;image ?</translation>
    </message>
    <message>
        <location filename="." line="49"/>
        <source> Merci d&apos;indiquer une échelle valable</source>
        <translation type="obsolete"> Merci d&apos;indiquer une échelle valable</translation>
    </message>
    <message>
        <location filename="." line="38"/>
        <source>Les données seront perdues</source>
        <translation type="obsolete">Les données seront perdues</translation>
    </message>
    <message>
        <location filename="." line="38"/>
        <source>Votre travail n&apos;a pas été sauvegardé
Voulez-vous les sauvegarder ?</source>
        <translation type="obsolete">Votre travail n&apos;a pas été sauvegardé
Voulez-vous les sauvegarder ?</translation>
    </message>
    <message>
        <location filename="." line="22"/>
        <source>Vous avez atteint le début de la vidéo</source>
        <translation type="obsolete">Vous avez atteint le début de la vidéo</translation>
    </message>
    <message>
        <location filename="." line="14"/>
        <source>Ouvrir une vidéo</source>
        <translation type="obsolete">Ouvrir une vidéo</translation>
    </message>
    <message>
        <location filename="." line="0"/>
        <source>fichiers vidéos ( *.avi *.mp4 *.ogv *.mpg *.mpeg *.ogg *.mov *.wmv)</source>
        <translation type="obsolete">fichiers vidéos ( *.avi *.mp4 *.ogv *.mpg *.mpeg *.ogg *.mov *.wmv)</translation>
    </message>
    <message>
        <location filename="." line="0"/>
        <source>fichiers vidéos ( *.avi *.mp4 *.ogv *.mpg *.mpeg *.ogg *.wmv *.mov)</source>
        <translation type="obsolete">fichiers vidéos ( *.avi *.mp4 *.ogv *.mpg *.mpeg *.ogg *.wmv *.mov)</translation>
    </message>
    <message>
        <location filename="." line="0"/>
        <source>Nom de fichier non conforme</source>
        <translation type="obsolete">Nom de fichier non conforme</translation>
    </message>
    <message>
        <location filename="." line="115413456"/>
        <source>Le nom de votre fichier contient des caractères accentués ou des espaces.
Merci de bien vouloir le renommer avant de continuer</source>
        <comment>utf8</comment>
        <translation type="obsolete">Le nom de votre fichier contient des caractères accentués ou des espaces.
Merci de bien vouloir le renommer avant de continuer</translation>
    </message>
    <message>
        <location filename="." line="0"/>
        <source>Veuillez choisir une image et définir l&apos;échelle</source>
        <translation type="obsolete">Veuillez choisir une image et définir l&apos;échelle</translation>
    </message>
    <message>
        <location filename="." line="0"/>
        <source>Désolé pas de fichier d&apos;aide pour le langage %1.</source>
        <translation type="obsolete">Désolé pas de fichier d&apos;aide pour le langage %1.</translation>
    </message>
    <message>
        <location filename="." line="0"/>
        <source>indÃ©f.</source>
        <translation type="obsolete">indéf.</translation>
    </message>
    <message>
        <location filename="." line="1232"/>
        <source>Le nom de votre fichier contient des caractÃ¨res accentuÃ©s ou des espaces.
Merci de bien vouloir le renommer avant de continuer</source>
        <translation type="obsolete">Le nom de votre fichier contient des caractères accentués ou des espaces.
Merci de bien vouloir le renommer avant de continuer</translation>
    </message>
</context>
<context>
    <name>pymecavideo</name>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="37"/>
        <source>PyMecaVideo, analyse mécanique des vidéos</source>
        <translation type="obsolete">PyMecaVideo, analyse mécanique des vidéos</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="86"/>
        <source>Acquisition des données</source>
        <translation type="obsolete">Acquisition des données</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="302"/>
        <source>Zoom</source>
        <translation type="obsolete">Zoom</translation>
    </message>
    <message>
        <location filename="pymecavideo_mini.ui" line="302"/>
        <source>Pointage</source>
        <translation type="obsolete">Pointage</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="384"/>
        <source>Démarrer</source>
        <translation type="obsolete">Démarrer</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="418"/>
        <source>efface la série précédente</source>
        <translation type="obsolete">efface la série précédente</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="455"/>
        <source>rétablit le point suivant</source>
        <translation type="obsolete">rétablit le point suivant</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="535"/>
        <source>Tout réinitialiser</source>
        <translation type="obsolete">Tout réinitialiser</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="551"/>
        <source>Définir l&apos;échelle</source>
        <translation type="obsolete">Définir l&apos;échelle</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="419"/>
        <source>indéf.</source>
        <translation type="obsolete">indéf.</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="621"/>
        <source>Points à 
 étudier:</source>
        <translation type="obsolete">Points à 
 étudier:</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="668"/>
        <source>Ordonnées 
vers le bas</source>
        <translation type="obsolete">Ordonnées 
vers le bas</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="58"/>
        <source>Lancer le logiciel
 d&apos;acquisition Vidéo</source>
        <translation type="obsolete">Lancer le logiciel
 d&apos;acquisition Vidéo</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="229"/>
        <source>Image n°</source>
        <translation type="obsolete">Image n°</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="937"/>
        <source>Voir la vidéo</source>
        <translation type="obsolete">Voir la vidéo</translation>
    </message>
    <message>
        <location filename="pymecavideo_mini.ui" line="897"/>
        <source>Depuis ce référentiel</source>
        <translation type="obsolete">Depuis ce référentiel</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="809"/>
        <source>Échelle de vitesses</source>
        <translation type="obsolete">Échelle de vitesses</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="369"/>
        <source>Acquisition</source>
        <translation type="obsolete">Acquisition</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="639"/>
        <source>suivi
automatique</source>
        <translation type="obsolete">suivi
automatique</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="650"/>
        <source>Changer d&apos;origine</source>
        <translation type="obsolete">Changer d&apos;origine</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1562"/>
        <source>Choisir ...</source>
        <translation>Choisir ...</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="897"/>
        <source>Chrono
photographie</source>
        <translation type="obsolete">Chrono
photographie</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="908"/>
        <source>Enregistrer</source>
        <translation type="obsolete">Enregistrer</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="972"/>
        <source>Coordonnées</source>
        <translation type="obsolete">Coordonnées</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="978"/>
        <source>Tableau des dates et des coordonnées</source>
        <translation type="obsolete">Tableau des dates et des coordonnées</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="984"/>
        <source>Copier les mesures dans le presse papier</source>
        <translation type="obsolete">Copier les mesures dans le presse papier</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="992"/>
        <source>Exporter vers ....</source>
        <translation type="obsolete">Exporter vers ....</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="997"/>
        <source>Oo.o Calc</source>
        <translation type="obsolete">Oo.o Calc</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1002"/>
        <source>Qtiplot</source>
        <translation type="obsolete">Qtiplot</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1007"/>
        <source>SciDAVis</source>
        <translation type="obsolete">SciDAVis</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1015"/>
        <source>changer d&apos;échelle ?</source>
        <translation type="obsolete">changer d&apos;échelle ?</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1055"/>
        <source>&amp;Fichier</source>
        <translation type="obsolete">&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1059"/>
        <source>E&amp;xporter vers ...</source>
        <translation type="obsolete">E&amp;xporter vers ...</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1076"/>
        <source>&amp;Aide</source>
        <translation type="obsolete">&amp;Aide</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1085"/>
        <source>&amp;Edition</source>
        <translation type="obsolete">&amp;Edition</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1102"/>
        <source>&amp;Ouvrir une vidéo (Ctrl-O)</source>
        <translation type="obsolete">&amp;Ouvrir une vidéo (Ctrl-O)</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1110"/>
        <source>avanceimage</source>
        <translation type="obsolete">avanceimage</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1115"/>
        <source>reculeimage</source>
        <translation type="obsolete">reculeimage</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1120"/>
        <source>Quitter (Ctrl-Q)</source>
        <translation type="obsolete">Quitter (Ctrl-Q)</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1128"/>
        <source>Enregistrer les données (Ctrl-S)</source>
        <translation type="obsolete">Enregistrer les données (Ctrl-S)</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1136"/>
        <source>À &amp;propos</source>
        <translation type="obsolete">À &amp;propos</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1141"/>
        <source>Aide (F1)</source>
        <translation type="obsolete">Aide (F1)</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1149"/>
        <source>Exemples ...</source>
        <translation type="obsolete">Exemples ...</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1154"/>
        <source>Ouvrir un projet &amp;mecavidéo</source>
        <translation type="obsolete">Ouvrir un projet &amp;mecavidéo</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1159"/>
        <source>&amp;Préférences</source>
        <translation type="obsolete">&amp;Préférences</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1164"/>
        <source>&amp;Copier dans le presse-papier (Ctrl-C)</source>
        <translation type="obsolete">&amp;Copier dans le presse-papier (Ctrl-C)</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1172"/>
        <source>Défaire (Ctrl-Z)</source>
        <translation type="obsolete">Défaire (Ctrl-Z)</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1180"/>
        <source>Refaire (Ctrl-Y)</source>
        <translation type="obsolete">Refaire (Ctrl-Y)</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1188"/>
        <source>OpenOffice.org &amp;Calc</source>
        <translation type="obsolete">OpenOffice.org &amp;Calc</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1193"/>
        <source>Qti&amp;plot</source>
        <translation type="obsolete">Qti&amp;plot</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1198"/>
        <source>Sci&amp;davis</source>
        <translation type="obsolete">Sci&amp;davis</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="189"/>
        <source>Pas de vidéos chargées</source>
        <translation type="obsolete">Pas de vidéos chargées</translation>
    </message>
    <message>
        <location filename="pymecavideo_mini.ui" line="280"/>
        <source>Acquisition video</source>
        <translation type="obsolete">Acquisition vidéo</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="782"/>
        <source>Montrer 
les vecteurs
vitesses</source>
        <translation type="obsolete">Montrer 
les vecteurs
vitesses</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="791"/>
        <source>près de
la souris</source>
        <translation type="obsolete">près de
la souris</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="802"/>
        <source>partout</source>
        <translation type="obsolete">partout</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="966"/>
        <source>Définir un autre référentiel : </source>
        <translation type="obsolete">Définir un autre référentiel : </translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="314"/>
        <source>Lancer %1
 pour capturer une vidÃ©o</source>
        <translation type="obsolete">Lancer %1
 pour capturer une vidéo</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="296"/>
        <source>indÃ©f</source>
        <translation>indéf</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="332"/>
        <source>NON DISPO : %1</source>
        <translation type="obsolete">NON DISPO : %1</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="994"/>
        <source>Ouvrir un projet Pymecavideo</source>
        <translation>Ouvrir un projet Pymecavideo</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="994"/>
        <source>fichiers pymecavideo(*.csv)</source>
        <translation>fichiers pymecavideo(*.csv)</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1300"/>
        <source>temps en seconde, positions en mÃ¨tre</source>
        <translation>temps en seconde, positions en mètre</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1245"/>
        <source>point NÂ° %1</source>
        <translation type="obsolete">point N° %1</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1393"/>
        <source>Veuillez sÃ©lectionner un cadre autour de(s) l&apos;objet(s) que vous voulez suivre.
Vous pouvez arrÃªter Ã&#xa0; tous moments la capture en appuyant sur le bouton</source>
        <translation>Veuillez sélectionner un cadre autour de(s) l&apos;objet(s) que vous voulez suivre.
Vous pouvez arrêter à tous moments la capture en appuyant sur le bouton</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1432"/>
        <source>Evolution de l&apos;abscisse du point %1</source>
        <translation type="obsolete">Evolution de l&apos;abscisse du point %1</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1432"/>
        <source>Evolution de l&apos;ordonnÃ©e du point %1</source>
        <translation type="obsolete">Evolution de l&apos;ordonnée du point %1</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1432"/>
        <source>Evolution de la vitesse du point %1</source>
        <translation type="obsolete">Evolution de la vitesse du point %1</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1496"/>
        <source>Pointage des positionsÂ&#xa0;: cliquer sur le point NÂ° %1</source>
        <translation type="obsolete">Pointage des positions : cliquer sur le point N° %1</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1665"/>
        <source>Vous avez atteint la fin de la vidÃ©o</source>
        <translation>Vous avez atteint la fin de la vidéo</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1871"/>
        <source>DÃ©finir une Ã©chelle</source>
        <translation>Définir une échelle</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1871"/>
        <source>Quelle est la longueur en mÃ¨tre de votre Ã©talon sur l&apos;image ?</source>
        <translation>Quelle est la longueur en mètre de votre étalon sur l&apos;image ?</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1892"/>
        <source> Merci d&apos;indiquer une Ã©chelle valable</source>
        <translation> Merci d&apos;indiquer une échelle valable</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1948"/>
        <source>Les donnÃ©es seront perdues</source>
        <translation>Les données seront perdues</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1948"/>
        <source>Votre travail n&apos;a pas Ã©tÃ© sauvegardÃ©
Voulez-vous les sauvegarder ?</source>
        <translation>Votre travail n&apos;a pas été sauvegardé
Voulez-vous les sauvegarder ?</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1782"/>
        <source>Vous avez atteint le dÃ©but de la vidÃ©o</source>
        <translation type="obsolete">Vous avez atteint le début de la vidéo</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="2011"/>
        <source>Ouvrir une vidÃ©o</source>
        <translation>Ouvrir une vidéo</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="2006"/>
        <source>Nom de fichier non conforme</source>
        <translation>Nom de fichier non conforme</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="2006"/>
        <source>Le nom de votre fichier contient des caractÃ¨res accentuÃ©s ou des espaces.
Merci de bien vouloir le renommer avant de continuer</source>
        <translation>Le nom de votre fichier contient des caractères accentués ou des espaces.
Merci de bien vouloir le renommer avant de continuer</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1862"/>
        <source>Veuillez choisir une image et dÃ©finir l&apos;Ã©chelle</source>
        <translation type="obsolete">Veuillez choisir une image et définir l&apos;échelle</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1907"/>
        <source>DÃ©solÃ© pas de fichier d&apos;aide pour le langage %1.</source>
        <translation type="obsolete">Désolé pas de fichier d&apos;aide pour le langage %1.</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1798"/>
        <source>fichiers vidÃ©os ( *.avi *.mp4 *.ogv *.mpg *.mpeg *.ogg *.mov *.wmv)</source>
        <translation type="obsolete">fichiers vidéos ( *.avi *.mp4 *.ogv *.mpg *.mpeg *.ogg *.mov *.wmv)</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1992"/>
        <source>fichiers vidÃ©os ( *.avi *.mp4 *.ogv *.mpg *.mpeg *.ogg *.wmv *.mov)</source>
        <translation>fichiers vidéos ( *.avi *.mp4 *.ogv *.mpg *.mpeg *.ogg *.wmv *.mov)</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="502"/>
        <source>Enregistrer la chronophotographie</source>
        <translation>Enregistrer la chronophotographie</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="502"/>
        <source>fichiers images(*.png *.jpg)</source>
        <translation>fichiers images(*.png *.jpg)</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="343"/>
        <source>NON DISPO : {0}</source>
        <translation>NON DISPO : {0}</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1251"/>
        <source>point N° {0}</source>
        <translation type="obsolete">point N° {0}</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1593"/>
        <source>Evolution de l&apos;abscisse du point {0}</source>
        <translation>Evolution de l&apos;abscisse du point {0}</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1446"/>
        <source>Evolution de l&apos;ordonnée du point {0}</source>
        <translation type="obsolete">Evolution de l&apos;ordonnée du point {0}</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1593"/>
        <source>Evolution de la vitesse du point {0}</source>
        <translation>Evolution de la vitesse du point {0}</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1494"/>
        <source>Pointage des positions&#xa0;: cliquer sur le point N° {0}</source>
        <translation type="obsolete">Pointage des positions : cliquer sur le point N° {0}</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1901"/>
        <source>Désolé pas de fichier d&apos;aide pour le langage {0}.</source>
        <translation type="obsolete">Désolé pas de fichier d&apos;aide pour le langage {0}.</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1898"/>
        <source>fichiers vidéos (*.avi *.mp4 *.ogv *.mpg *.mpeg *.ogg *.mov *.wmv)</source>
        <translation type="obsolete">fichiers vidéos (*.avi *.mp4 *.ogv *.mpg *.mpeg *.ogg *.mov *.wmv)</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1976"/>
        <source>Veuillez choisir une image (et définir l&apos;échelle)</source>
        <translation type="obsolete">Veuillez choisir une image (et définir l&apos;échelle)</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="2066"/>
        <source>Pymecavideo n&apos;arrive pas à lire l&apos;image</source>
        <translation type="obsolete">Pymecavideo n&apos;arrive pas à lire l&apos;image</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="882"/>
        <source>Fichier Python créé</source>
        <translation>Fichier Python créé</translation>
    </message>
</context>
<context>
    <name>self.app</name>
    <message>
        <location filename="../../src/cadreur.py" line="56"/>
        <source>Presser la touche ESC pour sortir</source>
        <translation>Presser la touche ESC pour sortir</translation>
    </message>
    <message>
        <location filename="../../src/echelle.py" line="159"/>
        <source>Choisir le nombre de points puis Â«Â&#xa0;DÃ©marrer l&apos;acquisitionÂ&#xa0;Â» </source>
        <translation>Choisir le nombre de points puis « Démarrer l&apos;acquisition » </translation>
    </message>
    <message>
        <location filename="../../src/echelle.py" line="164"/>
        <source>Vous pouvez continuer votre acquisition</source>
        <translation>Vous pouvez continuer votre acquisition</translation>
    </message>
    <message>
        <location filename="preferences.py" line="48"/>
        <source>Proximite de la souris %1</source>
        <translation type="obsolete">Proximité de la souris %1</translation>
    </message>
    <message>
        <location filename="preferences.py" line="49"/>
        <source>; derniere video %1</source>
        <translation type="obsolete">; dernière vidéo %1</translation>
    </message>
    <message>
        <location filename="preferences.py" line="50"/>
        <source>; videoDir %1</source>
        <translation type="obsolete">; videoDir %1</translation>
    </message>
    <message>
        <location filename="../../src/preferences.py" line="47"/>
        <source>Proximite de la souris {0}</source>
        <translation>Proximite de la souris {0}</translation>
    </message>
    <message>
        <location filename="../../src/preferences.py" line="48"/>
        <source>; derniere video {0}</source>
        <translation>; derniere video {0}</translation>
    </message>
    <message>
        <location filename="../../src/preferences.py" line="49"/>
        <source>; videoDir {0}</source>
        <translation>; videoDir {0}</translation>
    </message>
    <message>
        <location filename="../../src/cadreur.py" line="137"/>
        <source>Choisir le ralenti</source>
        <translation>Choisir le ralenti</translation>
    </message>
</context>
</TS>
